@@ -30,11 +30,11 @@ class PraatLoader:
                 f.write(self.scripts[s])
 
     def initlog(self):
-        with open(self.script_dir,'w') as f:
+        with open(os.path.join(self.script_dir,'log.txt'),'w') as f:
             f.write("begin")
 
     def updatelog(self,line):
-        with open(self.script_dir,'a') as f:
+        with open(os.path.join(self.script_dir,'log.txt'),'a') as f:
             f.write(line+"\n")
 
     def get_formants(self,filename,begin,end,nformants,ceiling):
